<?php

namespace Bixo\Database\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Database\Actions\CallAction;
use Bixo\Database\Http\Requests\CallActionRequest;
use Bixo\Database\Http\Resources\CallResource;
use Bixo\Database\Models\Call;

/**
 * Admin web controller class.
 */
class CallActionController extends BaseController
{

    /**
     * Action controller function for call.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CallActionRequest $request, Call $call, $action)
    {
        try {
            $request = $request->all();
            $call = CallAction::run($action, $call, $request);

            $data = new CallResource($call);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('database::call.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('database/call/' . $call->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('database/call/' . $call->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
