<?php

namespace Bixo\Database\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Database\Actions\CallReport;
use Bixo\Database\Http\Requests\CallReportRequest;

/**
 * Admin web controller class.
 */
class CallReportController extends BaseController
{
    /**
     * Action controller function for call.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CallReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Call::class);
            $data = CallReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('database::call.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('database/call/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('database/call/' . $report))
                ->redirect();
        }
    }
}
