<?php

namespace Bixo\Database\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Database\Actions\OwnerAction;
use Bixo\Database\Http\Requests\OwnerActionRequest;
use Bixo\Database\Http\Resources\OwnerResource;
use Bixo\Database\Models\Owner;

/**
 * Admin web controller class.
 */
class OwnerActionController extends BaseController
{

    /**
     * Action controller function for owner.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OwnerActionRequest $request, Owner $owner, $action)
    {
        try {
            $request = $request->all();
            $owner = OwnerAction::run($action, $owner, $request);

            $data = new OwnerResource($owner);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('database::owner.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('database/owner/' . $owner->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('database/owner/' . $owner->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
