<?php

namespace Bixo\Database\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Database\Actions\UploadAction;
use Bixo\Database\Http\Requests\UploadActionRequest;
use Bixo\Database\Http\Resources\UploadResource;
use Bixo\Database\Models\Upload;

/**
 * Admin web controller class.
 */
class UploadActionController extends BaseController
{

    /**
     * Action controller function for upload.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(UploadActionRequest $request, Upload $upload, $action)
    {
        try {
            $request = $request->all();
            $upload = UploadAction::run($action, $upload, $request);

            $data = new UploadResource($upload);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('database::upload.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('database/upload/' . $upload->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('database/upload/' . $upload->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
