<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\CallAction as CallActionEvent;
use Bixo\Database\Notifications\CallAction as CallActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CallAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CallActionEvent.
     *
     * @param   CallActionEvent  $event
     * @return mixed
     */
    public function handle(CallActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $call.
     *
     * @param   CallActionEvent  $event
     * @return void
     */
    public function create(CallActionEvent $event)
    {
        $client = $event->call->client;
        Notification::send($client, new CallActionNotification($event));
    }

    /**
     * Handle the CallActionEvent as a listener.
     *
     * @param   CallActionEvent  $event
     * @return mixed
     */
    public function asListener(CallActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CallActionEvent  $event
     * @return bool
     */
    private function isAllowed(CallActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
