<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\CallWorkflow as CallWorkflowEvent;
use Bixo\Database\Notifications\CallWorkflow as CallWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CallWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CallWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $call is submitted.
     *
     * @param CallWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CallWorkflowEvent $event)
    {
        $client = $event->call->client;
        Notification::send($client, new CallWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $call is published.
     *
     * @param CallWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CallWorkflowEvent $event)
    {
        $client = $event->call->client;
        Notification::send($client, new CallWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $call is approved.
     *
     * @param CallWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CallWorkflowEvent $event)
    {
        $client = $event->call->client;
        Notification::send($client, new CallWorkflowNotification($event));
    }

    /**
     * Handles the $call workflow event as a listener.
     *
     * @param CallWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CallWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
