<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\OwnerAction as OwnerActionEvent;
use Bixo\Database\Notifications\OwnerAction as OwnerActionNotification;
use Litepie\Actions\Concerns\AsAction;

class OwnerAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the OwnerActionEvent.
     *
     * @param   OwnerActionEvent  $event
     * @return mixed
     */
    public function handle(OwnerActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $owner.
     *
     * @param   OwnerActionEvent  $event
     * @return void
     */
    public function create(OwnerActionEvent $event)
    {
        $client = $event->owner->client;
        Notification::send($client, new OwnerActionNotification($event));
    }

    /**
     * Handle the OwnerActionEvent as a listener.
     *
     * @param   OwnerActionEvent  $event
     * @return mixed
     */
    public function asListener(OwnerActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   OwnerActionEvent  $event
     * @return bool
     */
    private function isAllowed(OwnerActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
