<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\OwnerWorkflow as OwnerWorkflowEvent;
use Bixo\Database\Notifications\OwnerWorkflow as OwnerWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OwnerWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OwnerWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $owner is submitted.
     *
     * @param OwnerWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OwnerWorkflowEvent $event)
    {
        $client = $event->owner->client;
        Notification::send($client, new OwnerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $owner is published.
     *
     * @param OwnerWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OwnerWorkflowEvent $event)
    {
        $client = $event->owner->client;
        Notification::send($client, new OwnerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $owner is approved.
     *
     * @param OwnerWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OwnerWorkflowEvent $event)
    {
        $client = $event->owner->client;
        Notification::send($client, new OwnerWorkflowNotification($event));
    }

    /**
     * Handles the $owner workflow event as a listener.
     *
     * @param OwnerWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OwnerWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
