<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\UploadAction as UploadActionEvent;
use Bixo\Database\Notifications\UploadAction as UploadActionNotification;
use Litepie\Actions\Concerns\AsAction;

class UploadAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the UploadActionEvent.
     *
     * @param   UploadActionEvent  $event
     * @return mixed
     */
    public function handle(UploadActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $upload.
     *
     * @param   UploadActionEvent  $event
     * @return void
     */
    public function create(UploadActionEvent $event)
    {
        $client = $event->upload->client;
        Notification::send($client, new UploadActionNotification($event));
    }

    /**
     * Handle the UploadActionEvent as a listener.
     *
     * @param   UploadActionEvent  $event
     * @return mixed
     */
    public function asListener(UploadActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   UploadActionEvent  $event
     * @return bool
     */
    private function isAllowed(UploadActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
