<?php

namespace Bixo\Database\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Database\Events\UploadWorkflow as UploadWorkflowEvent;
use Bixo\Database\Notifications\UploadWorkflow as UploadWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class UploadWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(UploadWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $upload is submitted.
     *
     * @param UploadWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(UploadWorkflowEvent $event)
    {
        $client = $event->upload->client;
        Notification::send($client, new UploadWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $upload is published.
     *
     * @param UploadWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(UploadWorkflowEvent $event)
    {
        $client = $event->upload->client;
        Notification::send($client, new UploadWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $upload is approved.
     *
     * @param UploadWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(UploadWorkflowEvent $event)
    {
        $client = $event->upload->client;
        Notification::send($client, new UploadWorkflowNotification($event));
    }

    /**
     * Handles the $upload workflow event as a listener.
     *
     * @param UploadWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(UploadWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
