<?php
namespace Bixo\Database\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Database\Events\CallAction as CallActionEvent;
use Bixo\Database\Models\Call;

class CallAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $call;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CallActionEvent $call
     */
    public function __construct(CallActionEvent $call)
    {
        $this->action = $event->action;
        $this->call = $call;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Call Approved - ' . config('app.name'))
            ->view('database::call.email.action', ['data' => $this->call]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
