<?php
namespace Bixo\Database\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Database\Events\OwnerAction as OwnerActionEvent;
use Bixo\Database\Models\Owner;

class OwnerAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $owner;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param OwnerActionEvent $owner
     */
    public function __construct(OwnerActionEvent $owner)
    {
        $this->action = $event->action;
        $this->owner = $owner;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Owner Approved - ' . config('app.name'))
            ->view('database::owner.email.action', ['data' => $this->owner]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
