<?php
namespace Bixo\Database\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Database\Events\UploadAction as UploadActionEvent;
use Bixo\Database\Models\Upload;

class UploadAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $upload;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param UploadActionEvent $upload
     */
    public function __construct(UploadActionEvent $upload)
    {
        $this->action = $event->action;
        $this->upload = $upload;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Upload Approved - ' . config('app.name'))
            ->view('database::upload.email.action', ['data' => $this->upload]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
