<?php

namespace Bixo\Database\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Database\Models\Call;

class CallPolicy
{

    use CallAction;
    use CallReport;
    use CallWorkflow;

    /**
     * Determine if the given user can view the call.
     *
     * @param Authenticatable $user
     * @param Call $call
     *
     * @return bool
     */
    public function view(Authenticatable $user, Call $call)
    {
        if ($authUser->canDo('database.call.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $call->is_owner;
    }

    /**
     * Determine if the given user can create a call.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('database.call.create');
    }

    /**
     * Determine if the given user can update the given call.
     *
     * @param Authenticatable $user
     * @param Call $call
     *
     * @return bool
     */
    public function update(Authenticatable $user, Call $call)
    {
        if ($user->canDo('database.call.edit') && $user->isAdmin()) {
            return true;
        }

        return $call->is_owner;
    }

    /**
     * Determine if the given user can delete the given call.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Call $call)
    {
        return $call->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
