<?php

namespace Bixo\Database\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Database\Models\Owner;

class OwnerPolicy
{

    use OwnerAction;
    use OwnerReport;
    use OwnerWorkflow;

    /**
     * Determine if the given user can view the owner.
     *
     * @param Authenticatable $user
     * @param Owner $owner
     *
     * @return bool
     */
    public function view(Authenticatable $user, Owner $owner)
    {
        if ($authUser->canDo('database.owner.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $owner->is_owner;
    }

    /**
     * Determine if the given user can create a owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('database.owner.create');
    }

    /**
     * Determine if the given user can update the given owner.
     *
     * @param Authenticatable $user
     * @param Owner $owner
     *
     * @return bool
     */
    public function update(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.edit') && $user->isAdmin()) {
            return true;
        }

        return $owner->is_owner;
    }

    /**
     * Determine if the given user can delete the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Owner $owner)
    {
        return $owner->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
