<?php

namespace Bixo\Database\Policies;

use Bixo\Database\Models\Owner;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait OwnerWorkflow
{

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given owner.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Owner $owner)
    {
        if ($user->canDo('database.owner.reject')) {
            return true;
        }

        return false;
    }

}
