<?php

namespace Bixo\Database\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Database\Models\Upload;

class UploadPolicy
{

    use UploadAction;
    use UploadReport;
    use UploadWorkflow;

    /**
     * Determine if the given user can view the upload.
     *
     * @param Authenticatable $user
     * @param Upload $upload
     *
     * @return bool
     */
    public function view(Authenticatable $user, Upload $upload)
    {
        if ($authUser->canDo('database.upload.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $upload->is_owner;
    }

    /**
     * Determine if the given user can create a upload.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('database.upload.create');
    }

    /**
     * Determine if the given user can update the given upload.
     *
     * @param Authenticatable $user
     * @param Upload $upload
     *
     * @return bool
     */
    public function update(Authenticatable $user, Upload $upload)
    {
        if ($user->canDo('database.upload.edit') && $user->isAdmin()) {
            return true;
        }

        return $upload->is_owner;
    }

    /**
     * Determine if the given user can delete the given upload.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Upload $upload)
    {
        return $upload->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
