<?php

namespace Bixo\Database\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Database\Databases;

class DatabaseServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'database');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'database');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Database\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Database\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Database\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Database\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.database', function($app)
        {
            return $this->app->make(Database::class);
        });
    }

    /**
     * Merges user's and database's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.database'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/call.php', 'bixo.database.call'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/owner.php', 'bixo.database.owner'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/upload.php', 'bixo.database.upload'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.database'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/database')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/database')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/database')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
